--------- WorldPay --------- WorldPay_, provides a hosted payments page for offsite transactions for merchants who cannot guarantee PCI compliance. The documentation for the service is available here_. After a transaction, WorldPay pings the notification URL and all the data sent is stored in the `RBSResponse` model instance that can be viewed from the django admin. The settings attribute required for this integration are: * **MD5_SECRET_KEY**: The MD5 secret key chosen by the user while signing up for the WorldPay Hosted Payments Service. Settings Attributes:: MERCHANT_TEST_MODE = True # Toggle for live MERCHANT_SETTINGS = { "world_pay": { "MD5_SECRET_KEY": "???" } ... } Example -------- In urls.py:: world_pay = get_integration("world_pay") urlpatterns += patterns('', (r'^world_pay/', include(world_pay.urls)), # You'll have to register /world_pay/rbs-notify-handler/ in the # WorldPay admin dashboard for the notification URL ) In views.py:: >>> from billing import get_integration >>> world_pay = get_integration("world_pay") >>> world_pay.add_fields({ ... "instId": "WP_ID", ... "cartId": "TEST123", ... "amount": 100, ... "currency": "USD", ... "desc": "Test Item", ... }) >>> return render_to_response("some_template.html", ... {"obj": world_pay}, ... context_instance=RequestContext(request)) In some_template.html:: {% load billing_tags %} {% world_pay obj %} Template renders to something like below:: .. _WorldPay: http://www.rbsworldpay.com/ .. _here: http://rbsworldpay.com/support/bg/index.php?page=development&sub=integration&c=UK